    	possibilities:

    		seeds:
    			sesame
    			chia
    			sunflower

    		beans:
    			cannellini
    			soy bean
    			black bean

    		rice:
    			basmati

    		nuts:
    			macadamia

    		?
    			bliss
    			sweet

    		plant internal systems

    		plants:
    			beans

    			nuts
    				pecan, walnut, almonds, cashews

    		planets

    		dinner, lunch, breakfast

    		types of plants

    		type of nutrients